@@ -114,9 +114,21 @@ subroutine expro_compute_derived
   expro_shape_scos2(:) = expro_rmin(:)*temp(:)
   call bound_deriv(temp,expro_shape_cos3,expro_rmin,expro_n_exp)
   expro_shape_scos3(:) = expro_rmin(:)*temp(:)
+  call bound_deriv(temp,expro_shape_cos4,expro_rmin,expro_n_exp)
+  expro_shape_scos4(:) = expro_rmin(:)*temp(:)
+  call bound_deriv(temp,expro_shape_cos5,expro_rmin,expro_n_exp)
+  expro_shape_scos5(:) = expro_rmin(:)*temp(:)
+  call bound_deriv(temp,expro_shape_cos6,expro_rmin,expro_n_exp)
+  expro_shape_scos6(:) = expro_rmin(:)*temp(:)
   call bound_deriv(temp,expro_shape_sin3,expro_rmin,expro_n_exp)
   expro_shape_ssin3(:) = expro_rmin(:)*temp(:)
-
+  call bound_deriv(temp,expro_shape_sin4,expro_rmin,expro_n_exp)
+  expro_shape_ssin4(:) = expro_rmin(:)*temp(:)
+  call bound_deriv(temp,expro_shape_sin5,expro_rmin,expro_n_exp)
+  expro_shape_ssin5(:) = expro_rmin(:)*temp(:)
+  call bound_deriv(temp,expro_shape_sin6,expro_rmin,expro_n_exp)
+  expro_shape_ssin6(:) = expro_rmin(:)*temp(:)
+  
   ! 1/L_ne = -dln(ne)/dr (1/m)
   call bound_deriv(expro_dlnnedr,-log(expro_ne),expro_rmin,expro_n_exp)
 
@@ -224,8 +236,20 @@ subroutine expro_compute_derived
      geo_shape_s_cos2_in = expro_shape_scos2(i)
      geo_shape_cos3_in   = expro_shape_cos3(i)
      geo_shape_s_cos3_in = expro_shape_scos3(i)
+     geo_shape_cos4_in   = expro_shape_cos4(i)
+     geo_shape_s_cos4_in = expro_shape_scos4(i)
+     geo_shape_cos5_in   = expro_shape_cos5(i)
+     geo_shape_s_cos5_in = expro_shape_scos5(i)
+     geo_shape_cos6_in   = expro_shape_cos6(i)
+     geo_shape_s_cos6_in = expro_shape_scos6(i)
      geo_shape_sin3_in   = expro_shape_sin3(i)
      geo_shape_s_sin3_in = expro_shape_ssin3(i)
+     geo_shape_sin4_in   = expro_shape_sin4(i)
+     geo_shape_s_sin4_in = expro_shape_ssin4(i)
+     geo_shape_sin5_in   = expro_shape_sin5(i)
+     geo_shape_s_sin5_in = expro_shape_ssin5(i)
+     geo_shape_sin6_in   = expro_shape_sin6(i)
+     geo_shape_s_sin6_in = expro_shape_ssin6(i)
      geo_beta_star_in = 0d0
      !
      theta(1) = 0d0
