@@ -166,7 +166,7 @@ elif plot_type == 'shift':
    ymin  = sys.argv[5]
    ymax  = sys.argv[6]
 
-   data_in.plot_shift(w=w,wmax=wmax,theta=theta,ymin=ymin,ymax=ymax)
+   head,x,y1,y2 = data_in.plot_shift(w=w,wmax=wmax,theta=theta,ymin=ymin,ymax=ymax)
 
    outfile = 'out.cgyro.shift.'+ftype
 
@@ -312,7 +312,10 @@ if doplot:
    if ftype == 'screen':
       plt.show()
    elif ftype == 'dump':
-      data = np.column_stack((x,y1,y2))
+      if y2 is None:
+         data = np.column_stack((x,y1))
+      else:
+         data = np.column_stack((x,y1,y2))
       np.savetxt(outfile,data,fmt='%.8e',header=head)
    else:
       plt.savefig(outfile)
