@@ -11,8 +11,9 @@ from mayavi import mlab
 try:
    from pygacode import vis
    from pygacode import geo
+   print("INFO: (vis_torcut) Successfully imported vis")
 except:
-   print("ERROR: (vis_torcut) Please type 'make so' in gacode/f2py")
+   print("ERROR: (vis_torcut) Please type 'pip install pygacode'")
    sys.exit()
 
 ext      = sys.argv[1]
