@@ -55,15 +55,19 @@ def plot_select(ax,tag):
    a = expro.expro_rmin[-1]
    csa = expro.expro_cs/a
 
-   sname = gapystr(expro.expro_name) 
+   sname = gapystr(expro.expro_name)
    stype = gapystr(expro.expro_type)
+
+   # Set roman font
+   for p in range(n):
+      sname[p] = '\mathrm{'+sname[p]+'}'
    
    # Set x-range
    m1 = 0 ; m2 = len(x)
    if rmax != 'auto':
-      m2 = np.argmin(np.abs(x-np.float(rmax)))
+      m2 = np.argmin(np.abs(x-float(rmax)))
    if rmin != 'auto':
-      m1 = np.argmin(np.abs(x-np.float(rmin)))
+      m1 = np.argmin(np.abs(x-float(rmin)))
       
    ax.set_xlim([x[m1],x[m2-1]])
 
@@ -149,13 +153,28 @@ def plot_select(ax,tag):
        y = np.arcsin(expro.expro_delta) ; ystr = 's_1 = \sin^{-1}\delta' ; plotit(ax,x,y,ystr)
        y = -expro.expro_zeta         ; ystr = 's_2 = -\zeta' ; plotit(ax,x,y,ystr)
        y = expro.expro_shape_sin3    ; ystr = 's_3' ; plotit(ax,x,y,ystr)
-     
+       y = expro.expro_shape_sin4    ; ystr = 's_4' ; plotit(ax,x,y,ystr)
+         
    if tag == 'cos':
        y = expro.expro_shape_cos0 ; ystr = 'c_0' ; plotit(ax,x,y,ystr)
        y = expro.expro_shape_cos1 ; ystr = 'c_1' ; plotit(ax,x,y,ystr)
        y = expro.expro_shape_cos2 ; ystr = 'c_2' ; plotit(ax,x,y,ystr)
        y = expro.expro_shape_cos3 ; ystr = 'c_3' ; plotit(ax,x,y,ystr)
-     
+       y = expro.expro_shape_cos4 ; ystr = 'c_4' ; plotit(ax,x,y,ystr)
+
+   if tag == 'ssin':
+       y = expro.expro_sdelta       ; ystr = 's_1 = \sin^{-1}\delta' ; plotit(ax,x,y,ystr)
+       y = -expro.expro_szeta       ; ystr = 's_2 = -\zeta' ; plotit(ax,x,y,ystr)
+       y = expro.expro_shape_ssin3  ; ystr = 's_3' ; plotit(ax,x,y,ystr)
+       y = expro.expro_shape_ssin4  ; ystr = 's_4' ; plotit(ax,x,y,ystr)
+
+   if tag == 'scos':
+       y = expro.expro_shape_scos0 ; ystr = 'c_0' ; plotit(ax,x,y,ystr)
+       y = expro.expro_shape_scos1 ; ystr = 'c_1' ; plotit(ax,x,y,ystr)
+       y = expro.expro_shape_scos2 ; ystr = 'c_2' ; plotit(ax,x,y,ystr)
+       y = expro.expro_shape_scos3 ; ystr = 'c_3' ; plotit(ax,x,y,ystr)
+       y = expro.expro_shape_scos4 ; ystr = 'c_4' ; plotit(ax,x,y,ystr)
+
    if tag == 'q':
        y = expro.expro_q ; ystr = 'q'
        if y[0] < 0.0:
@@ -175,11 +194,31 @@ def plot_select(ax,tag):
        y = expro.expro_volp ; ystr = 'V^\prime/a^2' ; plotit(ax,x,y/a**2,ystr)
        y = expro.expro_surf ; ystr = 'S/a^2' ; plotit(ax,x,y/a**2,ystr)
 
-   if tag == 'pow':
-      y = expro.expro_qbrem ; ystr = 'q_\mathrm{brem}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
-      y = expro.expro_qsync ; ystr = 'q_\mathrm{sync}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
-      y = expro.expro_qfusi ; ystr = 'q_{\\alpha i}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
+   if tag == 'Pe':
+      y = expro.expro_qohme+expro.expro_qbeame+expro.expro_qrfe+expro.expro_qione
+      yt = y
+      ystr = 'q_{e,\mathrm{aux}}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
       y = expro.expro_qfuse ; ystr = 'q_{\\alpha e}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
+      yt = yt+y
+      y = -expro.expro_qbrem ; ystr = '-q_\mathrm{brem}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
+      yt = yt+y
+      y = -expro.expro_qsync ; ystr = '-q_\mathrm{sync}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
+      yt = yt+y
+      y = -expro.expro_qline ; ystr = '-q_\mathrm{line}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
+      yt = yt+y
+      y = -expro.expro_qei ; ystr = '-q_{ei}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
+      yt = yt+y
+      ystr = 'q_{e}^\mathrm{TOT}~\mathrm{[MW/m^3]}' ; plotit(ax,x,yt,ystr)
+      
+   if tag == 'Pi':
+      y = expro.expro_qcxi+expro.expro_qbeami+expro.expro_qrfi+expro.expro_qioni
+      yt = y
+      ystr = 'q_{i,\mathrm{aux}}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
+      y = expro.expro_qfusi ; ystr = 'q_{\\alpha i}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
+      yt = yt+y
+      y = expro.expro_qei ; ystr = 'q_{ei}~\mathrm{[MW/m^3]}' ; plotit(ax,x,y,ystr)
+      yt = yt+y
+      ystr = 'q_{i}^\mathrm{TOT}~\mathrm{[MW/m^3]}' ; plotit(ax,x,yt,ystr)
 
    ax.legend(loc=loc,ncol=2)
        
@@ -217,9 +256,9 @@ class DemoFrame(wx.Frame):
  
         notebook = wx.Notebook(panel)
 
-        mytabs = ['r','R','Z','kappa','sin','cos','q','Bunit',
+        mytabs = ['r','R','Z','kappa','sin','cos','scos','ssin','q','Bunit',
                   'n','Ln','sn','T','LT','sT','gam_e','gam_p','Mach',
-                  'j','nu','rhos','V','pow']
+                  'j','nu','rhos','V','Pe','Pi']
 
         for x in mytabs:
            tab = TabPanel(notebook)
