@@ -167,7 +167,8 @@ def prgen_contour(geqdsk,nrz,levels,psinorm,narc,quiet):
     flxm=np.nanmin(psi2d)
     flxM=np.nanmax(psi2d)
         
-    kdbgmax=100
+    kdbgmax=50
+    forbidden=[]
     psi1 = None
     for kdbg in range(kdbgmax):
 
@@ -179,17 +180,21 @@ def prgen_contour(geqdsk,nrz,levels,psinorm,narc,quiet):
             if not np.isnan(path.vertices[:]).any() and np.allclose(path.vertices[0,0],path.vertices[-1,0]) and np.allclose(path.vertices[0,1],path.vertices[-1,1]):
                 path.vertices[0,0] = path.vertices[-1,0] = (path.vertices[0,0]+path.vertices[-1,0])*0.5
                 path.vertices[0,1] = path.vertices[-1,1] = (path.vertices[0,1]+path.vertices[-1,1])*0.5
-                simplePath=mp.Path(path.vertices[::len(path.vertices[:,0])//10+1,:])
-                if (np.max(simplePath.vertices[:,0]) > raxis_new and
-                    np.min(simplePath.vertices[:,0]) < raxis_new and
-                    np.max(simplePath.vertices[:,1]) > zaxis_new and
-                    np.min(simplePath.vertices[:,1]) < zaxis_new):
-                    if simplePath.contains_point((raxis_new,zaxis_new)):
-                        dR = path.vertices[1,0]-path.vertices[0,0]
-                        dZ = path.vertices[1,1]-path.vertices[0,1]
-                        orientation = int(np.sign((path.vertices[0,1]-zaxis_new)*dR-(path.vertices[0,0]-raxis_new)*dZ))
-                        line=path.vertices[::orientation,:]
-                        break
+                simplePath=mp.Path(path.vertices)
+                if np.max(simplePath.vertices[:,0])>raxis_new and np.min(simplePath.vertices[:,0])<raxis_new and  np.max(simplePath.vertices[:,1])>zaxis_new and min(simplePath.vertices[:,1])<zaxis_new and simplePath.contains_point((raxis_new,zaxis_new)) and not any([simplePath.contains_point((Rf,Zf)) for Rf,Zf in forbidden]):
+                    dR = path.vertices[1,0]-path.vertices[0,0]
+                    dZ = path.vertices[1,1]-path.vertices[0,1]
+                    orientation = int(np.sign((path.vertices[0,1]-zaxis_new)*dR-(path.vertices[0,0]-raxis_new)*dZ))
+                    line=path.vertices[::orientation,:]
+                else:
+                    Rf=np.mean(path.vertices[:,0])
+                    Zf=np.mean(path.vertices[:,1])
+                    if any([simplePath.contains_point((Rf,Zf)) for Rf,Zf in forbidden]):
+                        pass
+                    elif sep is not None and mp.Path(sep).contains_point((Rf,Zf)):
+                        pass
+                    else:
+                        forbidden.append([Rf,Zf])
             
         if len(line):
             try:
@@ -209,7 +214,7 @@ def prgen_contour(geqdsk,nrz,levels,psinorm,narc,quiet):
     if kdbg == kdbgmax-1:
         print('WARNING: (prgen_contour) Finding LCFS aborted after %d iterations!'%kdbgmax)
 
-    print('INFO  (prgen_contour) dpsi = {:.9f} [EFIT] {:.9f} [new]'.format(efitpsi1-efitpsi0,psi1-psi0))
+    print('INFO: (prgen_contour) dpsi = {:.9f} [EFIT] {:.9f} [new]'.format(efitpsi1-efitpsi0,psi1-psi0))
 
     # Separatrix hits edges of computation domain
     if ((np.abs(np.min(sep[:,0])-np.min(r2d)) < 1e-3) or
@@ -237,6 +242,8 @@ def prgen_contour(geqdsk,nrz,levels,psinorm,narc,quiet):
     RI = np.zeros([narc,levels]) ; ZI = np.zeros([narc,levels])
     r1 = np.zeros([narc])        ; z1 = np.zeros([narc])
 
+    kbad = []
+    
     for k,item1 in enumerate(contours):
         if k==0:
             # axis
@@ -247,11 +254,10 @@ def prgen_contour(geqdsk,nrz,levels,psinorm,narc,quiet):
             # Reverse order (compared to original OMFIT order)
             r=path.vertices[::-1,0] ; r[-1] = r[0]
             z=path.vertices[::-1,1] ; z[-1] = z[0]
-            # check for contour above separatrix
+
+            # check for contour above/below separatrix
             if np.average(z) > np.max(sep[:,1]) or np.average(z) < np.min(sep[:,1]):
-                path=item1[-2]
-                r=path.vertices[::-1,0] ; r[-1] = r[0]
-                z=path.vertices[::-1,1] ; z[-1] = z[0]
+                kbad.append(k)
                 
             if any(np.isnan(r*z)):
                 print('ERROR: (prgen_contour) NaN encountered')
@@ -272,7 +278,13 @@ def prgen_contour(geqdsk,nrz,levels,psinorm,narc,quiet):
             
         RI[:,k] = r1[:] ; ZI[:,k] = z1[:]
 
-        
+
+    # Delete bad contours (outside separatrix)
+    out_psi = np.delete(out_psi,kbad)
+    RI = np.delete(RI,kbad,1)
+    ZI = np.delete(ZI,kbad,1)
+    levels = len(out_psi)
+    
     efitpsi = np.linspace(out_psi[0],out_psi[-1],len(efitp))
     cs = interpolate.interp1d(efitpsi,efitp,kind='quadratic') ; out_p = cs(out_psi)
     cs = interpolate.interp1d(efitpsi,efitf,kind='quadratic') ; out_f = cs(out_psi)
@@ -282,7 +294,7 @@ def prgen_contour(geqdsk,nrz,levels,psinorm,narc,quiet):
     loopint = np.zeros([levels])
     for i in range(narc-1):
        loopint[:] = loopint[:]+(RI[i+1,:]-RI[i,:])*(ZI[i+1,:]+ZI[i,:])/(RI[i+1,:]+RI[i,:])
-      
+   
     cs = interpolate.splrep(out_psi,loopint) ; out_q = interpolate.splev(out_psi,cs,der=1)
     out_q = out_f*out_q/(2*np.pi)
     
